<?php
/**
 * @version    0.0.1
 * @package    com_ganewsletter
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2021 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace GlennArkell\Component\Ganewsletter\Administrator\Helper;

// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\User\UserHelper;
use \Joomla\CMS\User\UserFactoryInterface;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Component\ComponentHelper;
use \Joomla\Filesystem\Path;
use \Joomla\Filesystem\File;
use \Joomla\Filesystem\Folder;
use \Joomla\CMS\User\User;
use \Joomla\CMS\Date\Date;
use \Joomla\CMS\Access\Access;
use \Joomla\CMS\Installer\Installer;

/**
 * Ganewsletter helper.
 * @since  1.6
 */
class GaemailHelper
{
	/**
	 * Send out an email
	 * @param   array   $recipients  mandatory
	 * @param   string  $body  - text of the email body
	 * @param   string  $subject  - text for the subject line
	 * @param   string  $attachfile - file location address
	 * @return  boolean	false on fail
	 */
    public static function sendEmail($recipients, $body, $subject, $attachfile)
	{
        $params = ComponentHelper::getParams('com_ganewsletter');
        $test = $params->get('set_test', 0);
        $testUID = $params->get('user_id', 0);
        $headfoot = $params->get('html_headfoot', 0);
        $header = $params->get('html_header', null);
        $footer = $params->get('html_footer', null);

        if ($headfoot) {
            $body = $header . $body . $footer;
        }

	    $app		= Factory::getApplication();
        $mailfrom	= $app->get('mailfrom');       // system email address
        $fromname	= $app->get('fromname');       // Site name or system name

        // Build the email and send
        $mail = Factory::getMailer();
        $mail->isHTML(true);
		$mail->addRecipient($recipients);
		$mail->setSender(array($mailfrom, $fromname));
		$mail->setSubject($subject);
		$mail->setBody($body);
		if (is_file($attachfile)) {
            $mail->addAttachment($attachfile);
        }
        
        if ($test) {
            if ($testUID) {
                $sent = $mail->Send();
            }
        } else {
            $sent = $mail->Send();
        }
        return true;
	}

	/**
	 * Send out an email using the template layout
	 * @param   string  $template_id  mandatory (full template_id ie com_gabarebone.mail)
	 * @param   email   $email  mandatory - recipient email address
	 * @param   string  $name  mandatory - recipient name
	 * @param   string  $link  optional
	 * @return  boolean	false on fail
	 */
    public static function sendEmailTmpl($template_id, $email, $name, $link = null)
	{
        $params = ComponentHelper::getParams('com_ganewsletter');
	    $app		= Factory::getApplication();

        $data = array();
        $data['sitename'] = $app->get('sitename');
        if ($link) {
            $mode = $app->get('force_ssl', 0) == 2 ? 1 : (-1);
            $data['link_text'] = Route::_($link, false, $mode);
        }
        $data['name'] = $name;

        // Build the email and send
        $mailer = new MailTemplate($template_id, $app->getLanguage()->getTag());
        $mailer->addTemplateData($data);
        $mailer->addRecipient($email, $name);

        // Try to send the email.
        try {
            if (!$params->get('block_email', 0)) {
                return $mailer->send();
            }
            return true;
        } catch (\Exception $exception) {
            Factory::getApplication()->enqueueMessage(Text::_($exception->getMessage()), 'warning');
            return false;
        }

	}

}

