<?php
/**
 * @version    0.0.1
 * @package    com_ganewsletter
 * @author     Glenn Arkell <glenn@glennarkell.com.au>
 * @copyright  2021 Glenn Arkell
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace GlennArkell\Component\Ganewsletter\Administrator\Helper;

// No direct access
defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\MVC\Model\ListModel;
use \Joomla\CMS\MVC\Model\BaseDatabaseModel;
use \Joomla\CMS\MVC\Model\ItemModel;
use \Joomla\Data\DataObject;
use \Joomla\CMS\Component\ComponentHelper;
use \Joomla\CMS\User\UserHelper;
use \Joomla\CMS\Installer\Installer;
use \Joomla\Filesystem\Path;
use \Joomla\CMS\Toolbar\Toolbar;
use \Joomla\CMS\Toolbar\ToolbarHelper;
use \Joomla\CMS\Access\Access;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\Date\Date;
use \Joomla\CMS\HTML\HTMLHelper;
use \GlennArkell\Component\Ganewsletter\Administrator\Helper\GanewsletterHelper;
use \GlennArkell\Component\Ganewsletter\Administrator\Helper\GapdfHelper;


// Load admin language file
$lang = Factory::getApplication()->getLanguage();
$lang->load('com_ganewsletter', JPATH_ADMINISTRATOR);

/**
 * Printout helper.
 */
class GanewsrptHelper
{
	/**
	* Create pdf report based on the article data
	* @param trip record id
	* @return true
	*/
	public static function createNewsReport($newsId = 0, $newsData = null)
	{
		$app = Factory::getApplication();

        $app->setUserState('com_ganewsletter.news.data',$newsData);
        $fileName = str_replace(" ", "_", $newsData->title);
        
        $app->setUserState('com_ganewsletter.page1.header',false);

        $article_list = json_decode($newsData->article_list);

		$params  = ComponentHelper::getParams('com_ganewsletter');
		$pg1_header = $params->get('pg1_header', 0);
		$newsLoc = $params->get('news_loc', 'newsletters');
		$imgSide = $params->get('column_side', 'left');
		$colWid = $params->get('column_width', '80');
		$remainTxt = (188 - $colWid);
        // check for header image only on page one
        if ($pg1_header) {
            $app->setUserState('com_ganewsletter.page1.header',true);
        }

        $pdf=new GapdfHelper("P","mm","A4");

		$pdf->SetMargins(10,10,10);

        $pdf->AddPage();
        $lh = 4;

        // reset for header image only on page one if necessary
        if ($pg1_header) {
            $app->setUserState('com_ganewsletter.page1.header',false);
        }

		foreach ($article_list as $article) {

			$newsArticle = GanewsletterHelper::getNewsArticle($article);

            $articleDetails = $newsArticle->fulltext > '' ? strip_tags($newsArticle->fulltext) : strip_tags($newsArticle->introtext);
            $images = json_decode($newsArticle->images);
            $introImg = HTMLHelper::cleanImageURL($images->image_intro);
            $fullImg = HTMLHelper::cleanImageURL($images->image_fulltext);

            $articleDetails = str_replace("’", "'", $articleDetails);
            $articleDetails = str_replace("", "", $articleDetails);

            // seup for the heading of the article
            $pdf->SetFont('Arial','B',14);
            $pdf->SetTextColor(255,0,0);
            $pdf->Cell(0, $lh, $newsArticle->title, 0, 1, "C");
            $pdf->Ln(4);
            $pdf->SetFont('Arial','',10);
            $pdf->SetTextColor(64,64,64);

            // check for an image in the article
            if ((isset($introImg->url) && $introImg->url > '') ||
                (isset($fullImg->url) && $fullImg->url > ''))
            {
                $articleImg = $introImg->url > '' ? $introImg : $fullImg;
                $img_type = substr($articleImg->url,-3);
                $img_type = $img_type > '' ? $img_type : 'jpg';

                // calc dimensions
                $variation = $articleImg->attributes['width'] / $articleImg->attributes['height'];
                $hght = $colWid / $variation;
                
                if ($imgSide == 'left') {
                    $imgSide = 'right';
                    $y = $pdf->GetY();  // vertical position for the start of the image
                    $pdf->Image(JPATH_SITE.'/'.$articleImg->url, $pdf->GetX(), $y, 0, $hght, $img_type, '');
                    $pdf->SetX($colWid+10);
                    $yImg = $pdf->GetY(); // vertical position after the image position
                    $pdf->Cell(2, $lh, " ", 0, 0, "L"); // Sets an spacer
                    $pdf->MultiCell($remainTxt, $lh, $articleDetails, 0, "L", false);
                    $yTxt = $pdf->GetY();
                    if ($yImg > $yTxt) { $pdf->SetY($yImg+5); } else { $pdf->SetY($yTxt+5); }
                } else {
                    $y = $pdf->GetY();
                    $imgSide = 'left';
                    $pdf->MultiCell(($remainTxt-10), $lh, $articleDetails, 0, "L", false);
                    $yTxt = $pdf->GetY();
                    $pdf->SetX($remainTxt);
                    $pdf->Cell(2, $lh, " ", 0, 0, "L"); // Sets an spacer
                    $pdf->Image(JPATH_SITE.'/'.$articleImg->url, $pdf->GetX(), $y, 0, $hght, $img_type, '');
                    $yImg = $pdf->GetY();
                    if ($yImg > $yTxt) { $pdf->SetY($yImg+5); } else { $pdf->SetY($yTxt+5); }
                }
            } else {
                // seup for the content of the article
                $pdf->MultiCell(190, $lh, $articleDetails, 0, "L", false);
            }
            
            $pdf->Cell(0, $lh, " ", 0, 1, "C");

            $pdf->Ln(8);

  		}

        $pdf->Ln(4);

        $path = Path::clean( JPATH_SITE . '/images/' . $newsLoc );
        $pdf->Output($path . "/News-".$fileName.".pdf", "F");
        
        $attachfile = Uri::base(). "/images/" . $newsLoc . "/News-".$fileName.".pdf";

		return $attachfile;

	}

	/**
	* Send pdf report to members
	* @param object newsletter record
	* @param string newsletter pdf file
	* @return true
	*/
	public static function despatchNews($newsData = null, $attachfile = 0)
	{
		$body = '';
        $subject = $newsData->title;
        $article_list = json_decode($newsData->article_list);

        $params  = ComponentHelper::getParams('com_ganewsletter');

		foreach ($article_list as $article) {
			$newsArticle = GanewsletterHelper::getNewsArticle($article);
            $articleDetails = $newsArticle->fulltext > '' ? $newsArticle->fulltext : $newsArticle->introtext;
            $images = json_decode($newsArticle->images);

            // add site url to links and images
            $articleDetails = str_replace('href="', 'href="'.Uri::base().'/', $articleDetails);
            $articleDetails = str_replace('src="', 'src="'.Uri::base().'/', $articleDetails);

            // add content to the body
            $body .= '<h3 style="text-align:center;">'.$newsArticle->title.'</h3>'.$articleDetails.'<h3>&nbsp;</h3>';
        }

		$members = GanewsletterHelper::getMembersDetails($params);
		
		foreach ($members as $m) {

    		$recipients = array();
            $ePref = $params->get('exclude_email_pref', 'noemail');
    		if ((strlen($ePref) > 0) && (substr($m->email, 0, strlen($ePref)) == $ePref) ) {
                // ignore this as a recipient
            } else {
                $recipients[] = $m->email;
            }
            if ($m->inc_altemail && $m->altemail > '') {
                $m->altemail = str_replace('"','',$m->altemail);
                if ((strlen($ePref) > 0) && (substr($m->altemail, 0, strlen($ePref)) == $ePref) ) {
                   // ignore this as a recipient
                } else {
                    $recipients[] = $m->altemail;
                }
            }

            if (!empty($recipients)) {
                GanewsletterHelper::sendEmail($recipients, $body, $subject, $attachfile);
            }
		}

		return true;

	}

}
