<?php
/**
 * @version    0.0.1
 * @package     com_ganewsletter
 * @copyright   Copyright (C) 2022. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Created by Glenn Arkell - http://www.glennarkell.com
 */

namespace GlennArkell\Component\Ganewsletter\Administrator\Helper;

defined('_JEXEC') or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\Component\ComponentHelper;
use \Joomla\CMS\Uri\Uri;
use \Joomla\CMS\User\UserHelper;
use \Joomla\CMS\Date\Date;
use \Joomla\CMS\HTML\HTMLHelper;
use \GlennArkell\Component\Ganewsletter\Administrator\Helper\GanewsletterHelper;
use \GlennArkell\Component\Ganewsletter\Administrator\Helper\fpdf\fpdf;

class GapdfHelper extends FPDF
{

    public function Header() {

		// get the current date-time based on timezone
		$date = GanewsletterHelper::getTodaysDate();
        $today = date_format($date, 'jS F Y');
        $lh = 5;

	    $app		= Factory::getApplication();
        $sitename	= $app->get('sitename');
        $news  = $app->getUserState('com_ganewsletter.news.data');
        $pg1  = $app->getUserState('com_ganewsletter.page1.header');

		$params  = ComponentHelper::getParams('com_ganewsletter');
        $pg1_header  = $params->get('pg1_header', 0);
        $rpt_header  = $params->get('rpt_header');
        $rpt_header = HTMLHelper::cleanImageURL($rpt_header);
        // cal dimensions
        $variation = $rpt_header->attributes['width'] / $rpt_header->attributes['height'];
        $hght = 190 / $variation;
        
        $urllink = Uri::base();

        $this->SetFont('Arial','B',8);
        $this->SetTextColor(0,100,148); // r,g,b
        $this->Ln(2);
        $this->Cell(0, $lh, $today, 0, 1, "R"); // Sets an indent of 20mm
        $this->SetFont('Arial','B',28);
        $this->SetTextColor(64,64,64); // r,g,b
        $this->Ln(4);
        $this->Cell(0, $lh, $news->title, 0, 1, "C");
        $this->Ln(4);
        $this->Cell(0, $lh, "", "T", 1, "C");

        $this->SetFont('Arial','B',10);
        $this->SetTextColor(0,100,148); // r,g,b
        $x = $this->GetX();
        $y = $this->GetY();
        if (!empty($rpt_header) && $pg1) {
            if (\file_exists(JPATH_SITE.'/'.$rpt_header->url)) {
                $img_type = substr($rpt_header->url,-3);
                $this->Image(JPATH_SITE.'/'.$rpt_header->url, $x, $y, 0, $hght, $img_type, $urllink);
                $this->Ln($hght);
            }
        }

        // main header information
        $this->SetFont('Arial','',10);
        $this->Cell(0, $lh, $sitename, 0, 1, "C");
        $this->Ln(2);
        $this->Cell(0, $lh, "", "T", 1, "C");
        $this->Ln(2);

    }

    public function Footer() {
        //This is the footer; it's repeated on each page.
        //enter filename: phpjabber logo, x position: (page width/2)-half the picture size,
        //y position: rough estimate, width, height, filetype, link: click it!
        //    $this->Image("logo.jpg", (8.5/2)-1.5, 9.8, 3, 1, "JPG", "http://www.glennarkell.com");
        $lh = 5;

        $this->SetY(-15);
        $this->SetFont('Arial','',8);
        $this->SetTextColor(64,64,64); // r,g,b
        $this->Cell(0, $lh, "", 'T', 1, "R");
        $this->Cell(0, $lh, "Page - ".$this->PageNo(), 0, 1, "R");
    }

}

